@@ -93,7 +93,7 @@ class LabeledScaleTest(unittest.TestCase):
         self.failUnlessRaises(Tkinter.TclError, ttk.LabeledScale, a='b')
 
 
-    def test_range(self):
+    def test_horizontal_range(self):
         lscale = ttk.LabeledScale(from_=0, to=10)
         lscale.pack()
         lscale.wait_visibility()
