@@ -1,4 +1,5 @@
 # -*- encoding: utf-8 -*-
+import sys
 import unittest
 import ttk
 
@@ -66,6 +67,12 @@ class InternalFunctionsTest(unittest.TestCase):
         # opts should remain unchanged
         self.failUnlessEqual(opts, orig_opts)
 
+        # passing values with spaces inside a tuple/list
+        check_against(
+            ttk._format_optdict(
+                {'option': ('one two', 'three')}),
+            {'-option': '{one two} three'})
+
         # ignore an option
         amount_opts = len(ttk._format_optdict(opts, ignore=(u'á'))) / 2
         self.failUnlessEqual(amount_opts, len(opts) - 1)
@@ -382,7 +389,9 @@ class InternalFunctionsTest(unittest.TestCase):
         for orig, expected in tests:
             self.failUnlessEqual(ttk._convert_stringval(orig), expected)
 
-        self.failUnlessRaises(UnicodeDecodeError, ttk._convert_stringval, 'á')
+        if sys.getdefaultencoding() == 'ascii':
+            self.failUnlessRaises(UnicodeDecodeError,
+                ttk._convert_stringval, 'á')
 
 
 class TclObjsToPyTest(unittest.TestCase):
