@@ -12,7 +12,7 @@ maintaining the widget state and invoking callbacks, all aspects
 of the widgets appearance lies at Themes.
 """
 
-__version__ = "0.2.5"
+__version__ = "0.2.6"
 
 __author__ = "Guilherme Polo <ggpolo@gmail.com>"
 
@@ -73,7 +73,11 @@ def _format_optdict(optdict, script=False, ignore=None):
                     v.append(unicode(val) if val else '{}')
                 else:
                     v.append(str(val))
-            value = format % ' '.join(v)
+
+            # format v according to the script option, but also check for
+            # space in any value in v in order to group them correctly
+            value = format % ' '.join(
+                ('{%s}' if ' ' in val else '%s') % val for val in v)
 
         if script and value == '':
             value = '{}' # empty string in Python is equivalent to {} in Tcl
@@ -374,8 +378,9 @@ class Style(object):
             query_opt = ('' if query_opt.startswith('-') else '-') + query_opt
             return self.tk.call(self._name, "configure", style, query_opt)
 
-        return _dict_from_tcltuple(self.tk.call(self._name, "configure", style,
-                                                *(_format_optdict(kw))))
+        return _dict_from_tcltuple(
+            self.tk.call(
+                self._name, "configure", style, *(_format_optdict(kw))))
 
 
     def map(self, style, query_opt=None, **kw):
@@ -388,11 +393,11 @@ class Style(object):
         one or more states and then a value."""
         if query_opt:
             query_opt = ('' if query_opt.startswith('-') else '-') + query_opt
-            return _list_from_statespec(self.tk.call(self._name, "map", style,
-                                                     query_opt))
+            return _list_from_statespec(
+                self.tk.call(self._name, "map", style, query_opt))
 
-        return _dict_from_tcltuple(self.tk.call(self._name, "map", style,
-                                                *(_format_mapdict(kw))))
+        return _dict_from_tcltuple(
+            self.tk.call(self._name, "map", style, *(_format_mapdict(kw))))
 
 
     def lookup(self, style, option, state=None, default=None):
@@ -446,15 +451,15 @@ class Style(object):
             lspec = "null" # could be any other word, but this may make sense
                            # when calling layout(style) later
 
-        return _list_from_layouttuple(self.tk.call(self._name, "layout", style,
-                                                   lspec))
+        return _list_from_layouttuple(
+            self.tk.call(self._name, "layout", style, lspec))
 
 
     def element_create(self, elementname, etype, *args, **kw):
         """Create a new element in the current theme of given etype."""
         spec, opts = _format_elemcreate(etype, False, *args, **kw)
         self.tk.call(self._name, "element", "create", elementname, etype,
-                     spec, *opts)
+            spec, *opts)
 
 
     def element_names(self):
@@ -478,10 +483,10 @@ class Style(object):
 
         if parent:
             self.tk.call(self._name, "theme", "create", themename,
-                         "-parent", parent, "-settings", script)
+                "-parent", parent, "-settings", script)
         else:
             self.tk.call(self._name, "theme", "create", themename,
-                         "-settings", script)
+                "-settings", script)
 
 
     def theme_settings(self, themename, settings):
@@ -688,8 +693,9 @@ class Combobox(Entry):
             exportselection, justify, height, postcommand, state,
             textvariable, values, width
         """
+        # The "values" option may need special formatting, so leave to
+        # _format_optdict the responsability to format it
         if "values" in kw:
-            # may need special formatting if any value is an empty string
             kw["values"] = _format_optdict({'v': kw["values"]})[1]
 
         Entry.__init__(self, master, "ttk::combobox", **kw)
@@ -697,7 +703,6 @@ class Combobox(Entry):
 
     def __setitem__(self, item, value):
         if item == "values":
-            # may need special formatting if any value is an empty string
             value = _format_optdict({item: value})[1]
 
         Entry.__setitem__(self, item, value)
@@ -707,7 +712,6 @@ class Combobox(Entry):
         """Custom Combobox configure, created to properly format the values
         option."""
         if "values" in kw:
-            # may need special formatting if any value is an empty string
             kw["values"] = _format_optdict({'v': kw["values"]})[1]
 
         return Entry.configure(self, cnf, **kw)
@@ -1324,15 +1328,10 @@ class Treeview(Widget):
         is specified, it is used as the item identifier, iid must not
         already exist in the tree. Otherwise, a new unique identifier
         is generated."""
-        opts, values = _format_optdict(kw, ignore='values'), kw.get('values')
-        # values may need special formatting if any value contains a space
-        if values:
-            values = map(unicode, values)
-            opts += ("-values",
-                ' '.join(('{%s}' if ' ' in v else '%s') % v for v in values))
+        opts = _format_optdict(kw)
         if iid:
-            res = self.tk.call(self._w, "insert", parent, index, "-id", iid,
-                               *opts)
+            res = self.tk.call(self._w, "insert", parent, index,
+                "-id", iid, *opts)
         else:
             res = self.tk.call(self._w, "insert", parent, index, *opts)
 
@@ -1442,7 +1441,7 @@ class Treeview(Widget):
         tagname). With no additional arguments, returns a dictionary of
         the option settings for tagname."""
         return _val_or_dict(kw, self.tk.call, self._w, "tag", "configure",
-                            tagname)
+            tagname)
 
 
     def tag_has(self, tagname, item=None):
@@ -1467,7 +1466,7 @@ class Treeview(Widget):
 # Extensions
 
 class LabeledScale(Frame, object):
-    """A Ttk Scale widget with a Ttk Label widget over it indicating its
+    """A Ttk Scale widget with a Ttk Label widget indicating its
     current value.
     
     The Ttk Scale can be accessed through instance.scale, and Ttk Label
@@ -1485,6 +1484,7 @@ class LabeledScale(Frame, object):
                 Defaults to 'top'.
         """
         self._label_top = kw.pop('compound', 'top') == 'top'
+
         Frame.__init__(self, master, **kw)
         self._variable = variable or Tkinter.IntVar(master)
         self._variable.set(from_)
